# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchLearnedInformation(Base):
	"""The SwitchLearnedInformation class encapsulates a required switchLearnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchLearnedInformation property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'switchLearnedInformation'

	def __init__(self, parent):
		super(SwitchLearnedInformation, self).__init__(parent)

	@property
	def OfChannelSwitchLearnedInfo(self):
		"""An instance of the OfChannelSwitchLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ofchannelswitchlearnedinfo.OfChannelSwitchLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ofchannelswitchlearnedinfo import OfChannelSwitchLearnedInfo
		return OfChannelSwitchLearnedInfo(self)

	@property
	def SwitchFlow131TriggerAttributes(self):
		"""An instance of the SwitchFlow131TriggerAttributes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflow131triggerattributes.SwitchFlow131TriggerAttributes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflow131triggerattributes import SwitchFlow131TriggerAttributes
		return SwitchFlow131TriggerAttributes(self)._select()

	@property
	def SwitchFlowLearnedInfo(self):
		"""An instance of the SwitchFlowLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowlearnedinfo.SwitchFlowLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowlearnedinfo import SwitchFlowLearnedInfo
		return SwitchFlowLearnedInfo(self)

	@property
	def SwitchFlowMatchCriteria131TriggerAttributes(self):
		"""An instance of the SwitchFlowMatchCriteria131TriggerAttributes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowmatchcriteria131triggerattributes.SwitchFlowMatchCriteria131TriggerAttributes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowmatchcriteria131triggerattributes import SwitchFlowMatchCriteria131TriggerAttributes
		return SwitchFlowMatchCriteria131TriggerAttributes(self)._select()

	@property
	def SwitchGroupLearnedInfo(self):
		"""An instance of the SwitchGroupLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchgrouplearnedinfo.SwitchGroupLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchgrouplearnedinfo import SwitchGroupLearnedInfo
		return SwitchGroupLearnedInfo(self)

	@property
	def SwitchMeterLearnedInfo(self):
		"""An instance of the SwitchMeterLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchmeterlearnedinfo.SwitchMeterLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchmeterlearnedinfo import SwitchMeterLearnedInfo
		return SwitchMeterLearnedInfo(self)

	@property
	def SwitchTableFeaturesStatLearnedInfo(self):
		"""An instance of the SwitchTableFeaturesStatLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchtablefeaturesstatlearnedinfo.SwitchTableFeaturesStatLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchtablefeaturesstatlearnedinfo import SwitchTableFeaturesStatLearnedInfo
		return SwitchTableFeaturesStatLearnedInfo(self)

	@property
	def EnableVendorExperimenterMessage(self):
		"""If true, the vendor message trigger configuration parameters are available.

		Returns:
			bool
		"""
		return self._get_attribute('enableVendorExperimenterMessage')
	@EnableVendorExperimenterMessage.setter
	def EnableVendorExperimenterMessage(self, value):
		self._set_attribute('enableVendorExperimenterMessage', value)

	@property
	def EthernetDestination(self):
		"""This describes the flow match value for ethernet destination address field.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestination')
	@EthernetDestination.setter
	def EthernetDestination(self, value):
		self._set_attribute('ethernetDestination', value)

	@property
	def EthernetSource(self):
		"""This describes the flow match value for ethernet source address field.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSource')
	@EthernetSource.setter
	def EthernetSource(self, value):
		self._set_attribute('ethernetSource', value)

	@property
	def EthernetType(self):
		"""This describes the Ethernet type of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ethernetType')
	@EthernetType.setter
	def EthernetType(self, value):
		self._set_attribute('ethernetType', value)

	@property
	def InPort(self):
		"""This describes the flow match value for input port field

		Returns:
			str
		"""
		return self._get_attribute('inPort')
	@InPort.setter
	def InPort(self, value):
		self._set_attribute('inPort', value)

	@property
	def IpDscp(self):
		"""This describes the flow match value for IP ToS field.

		Returns:
			str
		"""
		return self._get_attribute('ipDscp')
	@IpDscp.setter
	def IpDscp(self, value):
		self._set_attribute('ipDscp', value)

	@property
	def IpProtocol(self):
		"""This describes the flow match value for IP Protocol field.

		Returns:
			str
		"""
		return self._get_attribute('ipProtocol')
	@IpProtocol.setter
	def IpProtocol(self, value):
		self._set_attribute('ipProtocol', value)

	@property
	def Ipv4Source(self):
		"""This describes the flow match value for IPv4 source address field.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Source')
	@Ipv4Source.setter
	def Ipv4Source(self, value):
		self._set_attribute('ipv4Source', value)

	@property
	def Ipv4destination(self):
		"""This describes the flow match value for IPv4 destination address field.

		Returns:
			str
		"""
		return self._get_attribute('ipv4destination')
	@Ipv4destination.setter
	def Ipv4destination(self, value):
		self._set_attribute('ipv4destination', value)

	@property
	def IsOfChannelLearnedInformationRefreshed(self):
		"""If true, it denotes that the Learned Info for the OF Channels is received.

		Returns:
			bool
		"""
		return self._get_attribute('isOfChannelLearnedInformationRefreshed')

	@property
	def IsOfFlowsLearnedInformationRefreshed(self):
		"""If true, it denotes that the Flow Learned Info for the OF Channels is received.

		Returns:
			bool
		"""
		return self._get_attribute('isOfFlowsLearnedInformationRefreshed')

	@property
	def OutPort(self):
		"""This describes the flow match value for output port field.

		Returns:
			number
		"""
		return self._get_attribute('outPort')
	@OutPort.setter
	def OutPort(self, value):
		self._set_attribute('outPort', value)

	@property
	def OutPortInputMode(self):
		"""This describes the output port type.

		Returns:
			str(ofppMax|ofppInPort|ofppTable|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppNone|outPortCustom)
		"""
		return self._get_attribute('outPortInputMode')
	@OutPortInputMode.setter
	def OutPortInputMode(self, value):
		self._set_attribute('outPortInputMode', value)

	@property
	def TableId(self):
		"""This describes the table identifier. It indicates the next table in the packet processing pipeline.

		Returns:
			number
		"""
		return self._get_attribute('tableId')
	@TableId.setter
	def TableId(self, value):
		self._set_attribute('tableId', value)

	@property
	def TableIdInputMode(self):
		"""This describes the type of table from which flow statistics will be sought.

		Returns:
			str(allTables|emergency|tableIdCustom)
		"""
		return self._get_attribute('tableIdInputMode')
	@TableIdInputMode.setter
	def TableIdInputMode(self, value):
		self._set_attribute('tableIdInputMode', value)

	@property
	def TansportSource(self):
		"""This describes the flow match value for transport source field.

		Returns:
			str
		"""
		return self._get_attribute('tansportSource')
	@TansportSource.setter
	def TansportSource(self, value):
		self._set_attribute('tansportSource', value)

	@property
	def TransportDestination(self):
		"""This describes the flow match value for transport destination field.

		Returns:
			str
		"""
		return self._get_attribute('transportDestination')
	@TransportDestination.setter
	def TransportDestination(self, value):
		self._set_attribute('transportDestination', value)

	@property
	def VendorExperimenterId(self):
		"""This describes the ID of the vendor for which vendor message is triggered.

		Returns:
			number
		"""
		return self._get_attribute('vendorExperimenterId')
	@VendorExperimenterId.setter
	def VendorExperimenterId(self, value):
		self._set_attribute('vendorExperimenterId', value)

	@property
	def VendorExperimenterType(self):
		"""This describes the Type of experimenter only for v 1.3.

		Returns:
			number
		"""
		return self._get_attribute('vendorExperimenterType')
	@VendorExperimenterType.setter
	def VendorExperimenterType(self, value):
		self._set_attribute('vendorExperimenterType', value)

	@property
	def VendorMessage(self):
		"""This describes the vendor data of the vendor message trigger.

		Returns:
			str
		"""
		return self._get_attribute('vendorMessage')
	@VendorMessage.setter
	def VendorMessage(self, value):
		self._set_attribute('vendorMessage', value)

	@property
	def VendorMessageLength(self):
		"""This describes the length of vendor data of the vendor message trigger.

		Returns:
			number
		"""
		return self._get_attribute('vendorMessageLength')
	@VendorMessageLength.setter
	def VendorMessageLength(self, value):
		self._set_attribute('vendorMessageLength', value)

	@property
	def VlanId(self):
		"""This describes the flow match value for VLAN ID field.

		Returns:
			str
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	@property
	def VlanPriority(self):
		"""This describes the flow match value for VLAN Priority field.

		Returns:
			str
		"""
		return self._get_attribute('vlanPriority')
	@VlanPriority.setter
	def VlanPriority(self, value):
		self._set_attribute('vlanPriority', value)

	def update(self, EnableVendorExperimenterMessage=None, EthernetDestination=None, EthernetSource=None, EthernetType=None, InPort=None, IpDscp=None, IpProtocol=None, Ipv4Source=None, Ipv4destination=None, OutPort=None, OutPortInputMode=None, TableId=None, TableIdInputMode=None, TansportSource=None, TransportDestination=None, VendorExperimenterId=None, VendorExperimenterType=None, VendorMessage=None, VendorMessageLength=None, VlanId=None, VlanPriority=None):
		"""Updates a child instance of switchLearnedInformation on the server.

		Args:
			EnableVendorExperimenterMessage (bool): If true, the vendor message trigger configuration parameters are available.
			EthernetDestination (str): This describes the flow match value for ethernet destination address field.
			EthernetSource (str): This describes the flow match value for ethernet source address field.
			EthernetType (str): This describes the Ethernet type of the flow match.
			InPort (str): This describes the flow match value for input port field
			IpDscp (str): This describes the flow match value for IP ToS field.
			IpProtocol (str): This describes the flow match value for IP Protocol field.
			Ipv4Source (str): This describes the flow match value for IPv4 source address field.
			Ipv4destination (str): This describes the flow match value for IPv4 destination address field.
			OutPort (number): This describes the flow match value for output port field.
			OutPortInputMode (str(ofppMax|ofppInPort|ofppTable|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppNone|outPortCustom)): This describes the output port type.
			TableId (number): This describes the table identifier. It indicates the next table in the packet processing pipeline.
			TableIdInputMode (str(allTables|emergency|tableIdCustom)): This describes the type of table from which flow statistics will be sought.
			TansportSource (str): This describes the flow match value for transport source field.
			TransportDestination (str): This describes the flow match value for transport destination field.
			VendorExperimenterId (number): This describes the ID of the vendor for which vendor message is triggered.
			VendorExperimenterType (number): This describes the Type of experimenter only for v 1.3.
			VendorMessage (str): This describes the vendor data of the vendor message trigger.
			VendorMessageLength (number): This describes the length of vendor data of the vendor message trigger.
			VlanId (str): This describes the flow match value for VLAN ID field.
			VlanPriority (str): This describes the flow match value for VLAN Priority field.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def ClearRecordsForTrigger(self):
		"""Executes the clearRecordsForTrigger operation on the server.

		API to clear records for any trigger.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('clearRecordsForTrigger', payload=payload, response_object=None)

	def RefreshFlows(self):
		"""Executes the refreshFlows operation on the server.

		This describes that the flows learned information is refreshed.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshFlows', payload=payload, response_object=None)

	def RefreshGroupLearnedInformation(self):
		"""Executes the refreshGroupLearnedInformation operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshGroupLearnedInformation', payload=payload, response_object=None)

	def RefreshMeterLearnedInformation(self):
		"""Executes the refreshMeterLearnedInformation operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshMeterLearnedInformation', payload=payload, response_object=None)

	def RefreshOfChannelLearnedInformation(self):
		"""Executes the refreshOfChannelLearnedInformation operation on the server.

		This describes that the ofChannellearned information is refreshed.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshOfChannelLearnedInformation', payload=payload, response_object=None)

	def RefreshTableFeature(self):
		"""Executes the refreshTableFeature operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshTableFeature', payload=payload, response_object=None)

	def Trigger(self):
		"""Executes the trigger operation on the server.

		API to send Trigger.

			Returns:
				number: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('trigger', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Capabilities(Base):
	"""The Capabilities class encapsulates a required capabilities node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Capabilities property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'capabilities'

	def __init__(self, parent):
		super(Capabilities, self).__init__(parent)

	@property
	def FlowStatistics(self):
		"""Indicates that the ofChannel capabilities of the switch includes flow statistics.

		Returns:
			bool
		"""
		return self._get_attribute('flowStatistics')
	@FlowStatistics.setter
	def FlowStatistics(self, value):
		self._set_attribute('flowStatistics', value)

	@property
	def MatchIpAddressInArpPackets(self):
		"""Indicates that the ofChannel capabilities of the switch includes Match IP addresses in ARP pkts.

		Returns:
			bool
		"""
		return self._get_attribute('matchIpAddressInArpPackets')
	@MatchIpAddressInArpPackets.setter
	def MatchIpAddressInArpPackets(self, value):
		self._set_attribute('matchIpAddressInArpPackets', value)

	@property
	def PortStatistics(self):
		"""Indicates that the ofChannel capabilities of the switch includes port statistics.

		Returns:
			bool
		"""
		return self._get_attribute('portStatistics')
	@PortStatistics.setter
	def PortStatistics(self, value):
		self._set_attribute('portStatistics', value)

	@property
	def QueueStatistics(self):
		"""Indicates that the ofChannel capabilities of the switch include Queue statistics.

		Returns:
			bool
		"""
		return self._get_attribute('queueStatistics')
	@QueueStatistics.setter
	def QueueStatistics(self, value):
		self._set_attribute('queueStatistics', value)

	@property
	def ReassambleIpFragments(self):
		"""Indicates that the ofChannel capabilities of the switch include reassemble IP fragments at the receiver.

		Returns:
			bool
		"""
		return self._get_attribute('reassambleIpFragments')
	@ReassambleIpFragments.setter
	def ReassambleIpFragments(self, value):
		self._set_attribute('reassambleIpFragments', value)

	@property
	def Reserved(self):
		"""Indicates that the ofChannel capabilities of the switch includes reserved, must be zero.

		Returns:
			bool
		"""
		return self._get_attribute('reserved')
	@Reserved.setter
	def Reserved(self, value):
		self._set_attribute('reserved', value)

	@property
	def SpanningTree(self):
		"""Indicates that the ofChannel capabilities of the switch includes 802.1d spanning tree.

		Returns:
			bool
		"""
		return self._get_attribute('spanningTree')
	@SpanningTree.setter
	def SpanningTree(self, value):
		self._set_attribute('spanningTree', value)

	@property
	def TableStatistics(self):
		"""Indicates that the ofChannel capabilities of the switch includes table statistics.

		Returns:
			bool
		"""
		return self._get_attribute('tableStatistics')
	@TableStatistics.setter
	def TableStatistics(self, value):
		self._set_attribute('tableStatistics', value)

	def update(self, FlowStatistics=None, MatchIpAddressInArpPackets=None, PortStatistics=None, QueueStatistics=None, ReassambleIpFragments=None, Reserved=None, SpanningTree=None, TableStatistics=None):
		"""Updates a child instance of capabilities on the server.

		Args:
			FlowStatistics (bool): Indicates that the ofChannel capabilities of the switch includes flow statistics.
			MatchIpAddressInArpPackets (bool): Indicates that the ofChannel capabilities of the switch includes Match IP addresses in ARP pkts.
			PortStatistics (bool): Indicates that the ofChannel capabilities of the switch includes port statistics.
			QueueStatistics (bool): Indicates that the ofChannel capabilities of the switch include Queue statistics.
			ReassambleIpFragments (bool): Indicates that the ofChannel capabilities of the switch include reassemble IP fragments at the receiver.
			Reserved (bool): Indicates that the ofChannel capabilities of the switch includes reserved, must be zero.
			SpanningTree (bool): Indicates that the ofChannel capabilities of the switch includes 802.1d spanning tree.
			TableStatistics (bool): Indicates that the ofChannel capabilities of the switch includes table statistics.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def Duration(self):
		"""The wait time in hours, minutes, and seconds, that is required for the PTP protocol to negotiate

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableAllSlavesStatus(self):
		"""Master Clock ID of all the slave clocks is the same as the ID of the clock configured as Expected Master

		Returns:
			str
		"""
		return self._get_attribute('enableAllSlavesStatus')
	@EnableAllSlavesStatus.setter
	def EnableAllSlavesStatus(self, value):
		self._set_attribute('enableAllSlavesStatus', value)

	@property
	def EnableExpectedGrandMasterStatus(self):
		"""Status of the clock configured as Expected Master is Grand Master

		Returns:
			str
		"""
		return self._get_attribute('enableExpectedGrandMasterStatus')
	@EnableExpectedGrandMasterStatus.setter
	def EnableExpectedGrandMasterStatus(self, value):
		self._set_attribute('enableExpectedGrandMasterStatus', value)

	@property
	def EnableNonExpectedMasterStatus(self):
		"""Status of clocks configured as Master is not Grand Master

		Returns:
			str
		"""
		return self._get_attribute('enableNonExpectedMasterStatus')
	@EnableNonExpectedMasterStatus.setter
	def EnableNonExpectedMasterStatus(self, value):
		self._set_attribute('enableNonExpectedMasterStatus', value)

	@property
	def ExpectedMasterClockId(self):
		"""ID of the Expected Master Clock

		Returns:
			str
		"""
		return self._get_attribute('expectedMasterClockId')
	@ExpectedMasterClockId.setter
	def ExpectedMasterClockId(self, value):
		self._set_attribute('expectedMasterClockId', value)

	@property
	def ExpectedMasterPort(self):
		"""Port selected as Expected Master

		Returns:
			str
		"""
		return self._get_attribute('expectedMasterPort')
	@ExpectedMasterPort.setter
	def ExpectedMasterPort(self, value):
		self._set_attribute('expectedMasterPort', value)

	@property
	def GrandMasterStatus(self):
		"""Port selected as Grand Master Clock

		Returns:
			str
		"""
		return self._get_attribute('grandMasterStatus')
	@GrandMasterStatus.setter
	def GrandMasterStatus(self, value):
		self._set_attribute('grandMasterStatus', value)

	@property
	def MasterPorts(self):
		"""Ports selected as Master

		Returns:
			str
		"""
		return self._get_attribute('masterPorts')
	@MasterPorts.setter
	def MasterPorts(self, value):
		self._set_attribute('masterPorts', value)

	@property
	def MaxOutstanding(self):
		"""Maximum number of connection requests or tear down requests that can be pending at any one time

		Returns:
			number
		"""
		return self._get_attribute('maxOutstanding')
	@MaxOutstanding.setter
	def MaxOutstanding(self, value):
		self._set_attribute('maxOutstanding', value)

	@property
	def NonExpectedMasterStatus(self):
		"""Clocks configured as Master are not Grand Master

		Returns:
			str
		"""
		return self._get_attribute('nonExpectedMasterStatus')
	@NonExpectedMasterStatus.setter
	def NonExpectedMasterStatus(self, value):
		self._set_attribute('nonExpectedMasterStatus', value)

	@property
	def Numtrials(self):
		"""Number of trials that can be run

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def ProtocolItem(self):
		"""Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def Runmode(self):
		"""Running mode used

		Returns:
			str(duration|noframes)
		"""
		return self._get_attribute('runmode')
	@Runmode.setter
	def Runmode(self, value):
		self._set_attribute('runmode', value)

	@property
	def SetupRate(self):
		"""The number of PTP connections to be initiated per second

		Returns:
			number
		"""
		return self._get_attribute('setupRate')
	@SetupRate.setter
	def SetupRate(self, value):
		self._set_attribute('setupRate', value)

	@property
	def SlavePorts(self):
		"""The ports selected as slaves

		Returns:
			str
		"""
		return self._get_attribute('slavePorts')
	@SlavePorts.setter
	def SlavePorts(self, value):
		self._set_attribute('slavePorts', value)

	@property
	def StartTraffic(self):
		"""All traffic configured in IxNetwork is initiated on running this test

		Returns:
			str
		"""
		return self._get_attribute('startTraffic')
	@StartTraffic.setter
	def StartTraffic(self, value):
		self._set_attribute('startTraffic', value)

	@property
	def TeardownRate(self):
		"""The number of PTP connections to tear down per second

		Returns:
			number
		"""
		return self._get_attribute('teardownRate')
	@TeardownRate.setter
	def TeardownRate(self, value):
		self._set_attribute('teardownRate', value)

	@property
	def UseExistingSetupRate(self):
		"""Currently set Setup Rate value is used

		Returns:
			bool
		"""
		return self._get_attribute('useExistingSetupRate')
	@UseExistingSetupRate.setter
	def UseExistingSetupRate(self, value):
		self._set_attribute('useExistingSetupRate', value)

	def update(self, Duration=None, EnableAllSlavesStatus=None, EnableExpectedGrandMasterStatus=None, EnableNonExpectedMasterStatus=None, ExpectedMasterClockId=None, ExpectedMasterPort=None, GrandMasterStatus=None, MasterPorts=None, MaxOutstanding=None, NonExpectedMasterStatus=None, Numtrials=None, ProtocolItem=None, Runmode=None, SetupRate=None, SlavePorts=None, StartTraffic=None, TeardownRate=None, UseExistingSetupRate=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			Duration (number): The wait time in hours, minutes, and seconds, that is required for the PTP protocol to negotiate
			EnableAllSlavesStatus (str): Master Clock ID of all the slave clocks is the same as the ID of the clock configured as Expected Master
			EnableExpectedGrandMasterStatus (str): Status of the clock configured as Expected Master is Grand Master
			EnableNonExpectedMasterStatus (str): Status of clocks configured as Master is not Grand Master
			ExpectedMasterClockId (str): ID of the Expected Master Clock
			ExpectedMasterPort (str): Port selected as Expected Master
			GrandMasterStatus (str): Port selected as Grand Master Clock
			MasterPorts (str): Ports selected as Master
			MaxOutstanding (number): Maximum number of connection requests or tear down requests that can be pending at any one time
			NonExpectedMasterStatus (str): Clocks configured as Master are not Grand Master
			Numtrials (number): Number of trials that can be run
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			Runmode (str(duration|noframes)): Running mode used
			SetupRate (number): The number of PTP connections to be initiated per second
			SlavePorts (str): The ports selected as slaves
			StartTraffic (str): All traffic configured in IxNetwork is initiated on running this test
			TeardownRate (number): The number of PTP connections to tear down per second
			UseExistingSetupRate (bool): Currently set Setup Rate value is used

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SiteEidRange(Base):
	"""The SiteEidRange class encapsulates a user managed siteEidRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SiteEidRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'siteEidRange'

	def __init__(self, parent):
		super(SiteEidRange, self).__init__(parent)

	@property
	def Address(self):
		"""It gives details about the Ip address

		Returns:
			str
		"""
		return self._get_attribute('address')
	@Address.setter
	def Address(self, value):
		self._set_attribute('address', value)

	@property
	def Count(self):
		"""It details about the count

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def Enabled(self):
		"""It true, it enables the protocol

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Family(self):
		"""It describes which family it belongs to

		Returns:
			str(ipv4|ipv6)
		"""
		return self._get_attribute('family')
	@Family.setter
	def Family(self, value):
		self._set_attribute('family', value)

	@property
	def IncludeOrExclude(self):
		"""It decides whether to include or exclude

		Returns:
			str(include|exclude)
		"""
		return self._get_attribute('includeOrExclude')
	@IncludeOrExclude.setter
	def IncludeOrExclude(self, value):
		self._set_attribute('includeOrExclude', value)

	@property
	def InstanceId(self):
		"""It gives the instance id

		Returns:
			number
		"""
		return self._get_attribute('instanceId')
	@InstanceId.setter
	def InstanceId(self, value):
		self._set_attribute('instanceId', value)

	@property
	def PrefixLength(self):
		"""It gives details about the prefix length

		Returns:
			number
		"""
		return self._get_attribute('prefixLength')
	@PrefixLength.setter
	def PrefixLength(self, value):
		self._set_attribute('prefixLength', value)

	def update(self, Address=None, Count=None, Enabled=None, Family=None, IncludeOrExclude=None, InstanceId=None, PrefixLength=None):
		"""Updates a child instance of siteEidRange on the server.

		Args:
			Address (str): It gives details about the Ip address
			Count (number): It details about the count
			Enabled (bool): It true, it enables the protocol
			Family (str(ipv4|ipv6)): It describes which family it belongs to
			IncludeOrExclude (str(include|exclude)): It decides whether to include or exclude
			InstanceId (number): It gives the instance id
			PrefixLength (number): It gives details about the prefix length

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Address=None, Count=None, Enabled=None, Family=None, IncludeOrExclude=None, InstanceId=None, PrefixLength=None):
		"""Adds a new siteEidRange node on the server and retrieves it in this instance.

		Args:
			Address (str): It gives details about the Ip address
			Count (number): It details about the count
			Enabled (bool): It true, it enables the protocol
			Family (str(ipv4|ipv6)): It describes which family it belongs to
			IncludeOrExclude (str(include|exclude)): It decides whether to include or exclude
			InstanceId (number): It gives the instance id
			PrefixLength (number): It gives details about the prefix length

		Returns:
			self: This instance with all currently retrieved siteEidRange data using find and the newly added siteEidRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the siteEidRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Address=None, Count=None, Enabled=None, Family=None, IncludeOrExclude=None, InstanceId=None, PrefixLength=None):
		"""Finds and retrieves siteEidRange data from the server.

		All named parameters support regex and can be used to selectively retrieve siteEidRange data from the server.
		By default the find method takes no parameters and will retrieve all siteEidRange data from the server.

		Args:
			Address (str): It gives details about the Ip address
			Count (number): It details about the count
			Enabled (bool): It true, it enables the protocol
			Family (str(ipv4|ipv6)): It describes which family it belongs to
			IncludeOrExclude (str(include|exclude)): It decides whether to include or exclude
			InstanceId (number): It gives the instance id
			PrefixLength (number): It gives details about the prefix length

		Returns:
			self: This instance with matching siteEidRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of siteEidRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the siteEidRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class NetTopologyCustom(Base):
	"""The NetTopologyCustom class encapsulates a user managed netTopologyCustom node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the NetTopologyCustom property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'netTopologyCustom'

	def __init__(self, parent):
		super(NetTopologyCustom, self).__init__(parent)

	@property
	def LinkTable(self):
		"""An instance of the LinkTable class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.linktable.LinkTable)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.linktable import LinkTable
		return LinkTable(self)._select()

	@property
	def IncludeEntryPoint(self):
		"""if true, entry node belongs to ring topology, otherwise it is outside of ring

		Returns:
			bool
		"""
		return self._get_attribute('includeEntryPoint')
	@IncludeEntryPoint.setter
	def IncludeEntryPoint(self, value):
		self._set_attribute('includeEntryPoint', value)

	@property
	def LinkMultiplier(self):
		"""number of links between two nodes

		Returns:
			number
		"""
		return self._get_attribute('linkMultiplier')
	@LinkMultiplier.setter
	def LinkMultiplier(self, value):
		self._set_attribute('linkMultiplier', value)

	@property
	def NumberOfNodes(self):
		"""Number Of Nodes

		Returns:
			number
		"""
		return self._get_attribute('numberOfNodes')

	def update(self, IncludeEntryPoint=None, LinkMultiplier=None):
		"""Updates a child instance of netTopologyCustom on the server.

		Args:
			IncludeEntryPoint (bool): if true, entry node belongs to ring topology, otherwise it is outside of ring
			LinkMultiplier (number): number of links between two nodes

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, IncludeEntryPoint=None, LinkMultiplier=None):
		"""Adds a new netTopologyCustom node on the server and retrieves it in this instance.

		Args:
			IncludeEntryPoint (bool): if true, entry node belongs to ring topology, otherwise it is outside of ring
			LinkMultiplier (number): number of links between two nodes

		Returns:
			self: This instance with all currently retrieved netTopologyCustom data using find and the newly added netTopologyCustom data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the netTopologyCustom data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, IncludeEntryPoint=None, LinkMultiplier=None, NumberOfNodes=None):
		"""Finds and retrieves netTopologyCustom data from the server.

		All named parameters support regex and can be used to selectively retrieve netTopologyCustom data from the server.
		By default the find method takes no parameters and will retrieve all netTopologyCustom data from the server.

		Args:
			IncludeEntryPoint (bool): if true, entry node belongs to ring topology, otherwise it is outside of ring
			LinkMultiplier (number): number of links between two nodes
			NumberOfNodes (number): Number Of Nodes

		Returns:
			self: This instance with matching netTopologyCustom data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of netTopologyCustom data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the netTopologyCustom data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ovsdbcontroller(Base):
	"""The Ovsdbcontroller class encapsulates a user managed ovsdbcontroller node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ovsdbcontroller property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'ovsdbcontroller'

	def __init__(self, parent):
		super(Ovsdbcontroller, self).__init__(parent)

	@property
	def ClusterData(self):
		"""An instance of the ClusterData class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.clusterdata.ClusterData)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.clusterdata import ClusterData
		return ClusterData(self)._select()

	@property
	def Connector(self):
		"""An instance of the Connector class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return Connector(self)

	@property
	def ClearDumpDbFiles(self):
		"""

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clearDumpDbFiles')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def ConnectionType(self):
		"""DEPRECATED Connection should use TCP or TLS

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('connectionType')

	@property
	def ControllerTcpPort(self):
		"""DEPRECATED Specify the TCP port for the Controller

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('controllerTcpPort')

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DirectoryName(self):
		"""DEPRECATED Location of Directory in Client where the Certificate and Key Files are available

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('directoryName')

	@property
	def DumpdbDirectoryName(self):
		"""DEPRECATED Location of Directory in Client where the DumpDb Files are available

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dumpdbDirectoryName')

	@property
	def EnableLogging(self):
		"""DEPRECATED If true, Port debug logs will be recorded, Maximum recording will be upto 500 MB .

		Returns:
			bool
		"""
		return self._get_attribute('enableLogging')
	@EnableLogging.setter
	def EnableLogging(self, value):
		self._set_attribute('enableLogging', value)

	@property
	def EnableOvsdbServerIp(self):
		"""DEPRECATED 

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableOvsdbServerIp')

	@property
	def ErrorCode(self):
		"""DEPRECATED Error Code

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorCode')

	@property
	def ErrorDesc(self):
		"""DEPRECATED Description of Error occured

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorDesc')

	@property
	def ErrorLogDirectoryName(self):
		"""DEPRECATED Location of Directory in Client where the ErrorLog Files are available

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorLogDirectoryName')

	@property
	def ErrorLogicalSwitchName(self):
		"""DEPRECATED Error occured for this Logical Switch Name

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorLogicalSwitchName')

	@property
	def ErrorPhysicalSwitchName(self):
		"""DEPRECATED Error occured for this Physical Switch Name

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorPhysicalSwitchName')

	@property
	def ErrorTimeStamp(self):
		"""DEPRECATED Time Stamp at which Last Error occurred

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('errorTimeStamp')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FileCaCertificate(self):
		"""DEPRECATED CA Certificate File

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fileCaCertificate')

	@property
	def FileCertificate(self):
		"""DEPRECATED Certificate File

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fileCertificate')

	@property
	def FileHWGatewayCertificate(self):
		"""DEPRECATED HW Gateway Certificate File

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fileHWGatewayCertificate')

	@property
	def FilePrivKey(self):
		"""DEPRECATED Private Key File

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('filePrivKey')

	@property
	def HSCConfiguration(self):
		"""DEPRECATED Each VTEP has its own Hardware Switch Controller.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hSCConfiguration')

	@property
	def LatestDumpDbFileNames(self):
		"""DEPRECATED Api to fetch latest DumpDb Files

		Returns:
			str
		"""
		return self._get_attribute('latestDumpDbFileNames')
	@LatestDumpDbFileNames.setter
	def LatestDumpDbFileNames(self, value):
		self._set_attribute('latestDumpDbFileNames', value)

	@property
	def LatestErrorFileNames(self):
		"""DEPRECATED Api to fetch latest Error Files

		Returns:
			str
		"""
		return self._get_attribute('latestErrorFileNames')
	@LatestErrorFileNames.setter
	def LatestErrorFileNames(self, value):
		self._set_attribute('latestErrorFileNames', value)

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def OvsdbSchema(self):
		"""DEPRECATED Database schema

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ovsdbSchema')

	@property
	def OvsdbServerIp(self):
		"""DEPRECATED The IP address of the DUT or Ovs Server.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ovsdbServerIp')

	@property
	def PseudoConnectedTo(self):
		"""DEPRECATED GUI-only connection

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)
		"""
		return self._get_attribute('pseudoConnectedTo')
	@PseudoConnectedTo.setter
	def PseudoConnectedTo(self, value):
		self._set_attribute('pseudoConnectedTo', value)

	@property
	def PseudoConnectedToBfd(self):
		"""DEPRECATED GUI-only connection

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)
		"""
		return self._get_attribute('pseudoConnectedToBfd')
	@PseudoConnectedToBfd.setter
	def PseudoConnectedToBfd(self, value):
		self._set_attribute('pseudoConnectedToBfd', value)

	@property
	def PseudoConnectedToVxlanReplicator(self):
		"""DEPRECATED GUI-only connection

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)
		"""
		return self._get_attribute('pseudoConnectedToVxlanReplicator')
	@PseudoConnectedToVxlanReplicator.setter
	def PseudoConnectedToVxlanReplicator(self, value):
		self._set_attribute('pseudoConnectedToVxlanReplicator', value)

	@property
	def PseudoMultiplier(self):
		"""DEPRECATED Multiplier for GUI-only connection

		Returns:
			number
		"""
		return self._get_attribute('pseudoMultiplier')

	@property
	def PseudoMultiplierBfd(self):
		"""DEPRECATED Multiplier for GUI-only connection

		Returns:
			number
		"""
		return self._get_attribute('pseudoMultiplierBfd')

	@property
	def PseudoMultiplierVxlanReplicator(self):
		"""DEPRECATED Multiplier for GUI-only connection

		Returns:
			number
		"""
		return self._get_attribute('pseudoMultiplierVxlanReplicator')

	@property
	def Role(self):
		"""DEPRECATED The role of the OVSDB Controller.

		Returns:
			list(str[master|none|slave])
		"""
		return self._get_attribute('role')

	@property
	def ServerAddDeleteConnectionError(self):
		"""DEPRECATED API to retrieve error occured while Adding/ Deleting Server

		Returns:
			str
		"""
		return self._get_attribute('serverAddDeleteConnectionError')
	@ServerAddDeleteConnectionError.setter
	def ServerAddDeleteConnectionError(self, value):
		self._set_attribute('serverAddDeleteConnectionError', value)

	@property
	def ServerAddDeleteStatus(self):
		"""DEPRECATED Status of all servers Added/Deleted to Controller. Use Get Server Add/Delete Status, right click action to get current status

		Returns:
			str
		"""
		return self._get_attribute('serverAddDeleteStatus')

	@property
	def ServerConnectionIp(self):
		"""DEPRECATED The IP address of the DUT or Ovs Server which needs to be Added/Deleted.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('serverConnectionIp')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TableNames(self):
		"""DEPRECATED 

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tableNames')

	@property
	def TimeOut(self):
		"""DEPRECATED Transact request Time Out in seconds. For scale scenarios increase this Timeout value.

		Returns:
			number
		"""
		return self._get_attribute('timeOut')
	@TimeOut.setter
	def TimeOut(self, value):
		self._set_attribute('timeOut', value)

	@property
	def VerifyHWGatewayCertificate(self):
		"""DEPRECATED Verify HW Gateway Certificate

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('verifyHWGatewayCertificate')

	@property
	def VerifyPeerCertificate(self):
		"""DEPRECATED Verify Peer Certificate

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('verifyPeerCertificate')

	@property
	def Vxlan(self):
		"""DEPRECATED 

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)
		"""
		return self._get_attribute('vxlan')
	@Vxlan.setter
	def Vxlan(self, value):
		self._set_attribute('vxlan', value)

	@property
	def VxlanReplicator(self):
		"""DEPRECATED 

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)
		"""
		return self._get_attribute('vxlanReplicator')
	@VxlanReplicator.setter
	def VxlanReplicator(self, value):
		self._set_attribute('vxlanReplicator', value)

	def update(self, ConnectedVia=None, EnableLogging=None, LatestDumpDbFileNames=None, LatestErrorFileNames=None, Multiplier=None, Name=None, PseudoConnectedTo=None, PseudoConnectedToBfd=None, PseudoConnectedToVxlanReplicator=None, ServerAddDeleteConnectionError=None, StackedLayers=None, TimeOut=None, Vxlan=None, VxlanReplicator=None):
		"""Updates a child instance of ovsdbcontroller on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			EnableLogging (bool): If true, Port debug logs will be recorded, Maximum recording will be upto 500 MB .
			LatestDumpDbFileNames (str): Api to fetch latest DumpDb Files
			LatestErrorFileNames (str): Api to fetch latest Error Files
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			PseudoConnectedTo (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToBfd (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToVxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			ServerAddDeleteConnectionError (str): API to retrieve error occured while Adding/ Deleting Server
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			TimeOut (number): Transact request Time Out in seconds. For scale scenarios increase this Timeout value.
			Vxlan (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 
			VxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, EnableLogging=None, LatestDumpDbFileNames=None, LatestErrorFileNames=None, Multiplier=None, Name=None, PseudoConnectedTo=None, PseudoConnectedToBfd=None, PseudoConnectedToVxlanReplicator=None, ServerAddDeleteConnectionError=None, StackedLayers=None, TimeOut=None, Vxlan=None, VxlanReplicator=None):
		"""Adds a new ovsdbcontroller node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			EnableLogging (bool): If true, Port debug logs will be recorded, Maximum recording will be upto 500 MB .
			LatestDumpDbFileNames (str): Api to fetch latest DumpDb Files
			LatestErrorFileNames (str): Api to fetch latest Error Files
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			PseudoConnectedTo (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToBfd (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToVxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			ServerAddDeleteConnectionError (str): API to retrieve error occured while Adding/ Deleting Server
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			TimeOut (number): Transact request Time Out in seconds. For scale scenarios increase this Timeout value.
			Vxlan (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 
			VxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 

		Returns:
			self: This instance with all currently retrieved ovsdbcontroller data using find and the newly added ovsdbcontroller data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the ovsdbcontroller data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, EnableLogging=None, Errors=None, LatestDumpDbFileNames=None, LatestErrorFileNames=None, Multiplier=None, Name=None, PseudoConnectedTo=None, PseudoConnectedToBfd=None, PseudoConnectedToVxlanReplicator=None, PseudoMultiplier=None, PseudoMultiplierBfd=None, PseudoMultiplierVxlanReplicator=None, Role=None, ServerAddDeleteConnectionError=None, ServerAddDeleteStatus=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None, TimeOut=None, Vxlan=None, VxlanReplicator=None):
		"""Finds and retrieves ovsdbcontroller data from the server.

		All named parameters support regex and can be used to selectively retrieve ovsdbcontroller data from the server.
		By default the find method takes no parameters and will retrieve all ovsdbcontroller data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			EnableLogging (bool): If true, Port debug logs will be recorded, Maximum recording will be upto 500 MB .
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			LatestDumpDbFileNames (str): Api to fetch latest DumpDb Files
			LatestErrorFileNames (str): Api to fetch latest Error Files
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			PseudoConnectedTo (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToBfd (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoConnectedToVxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): GUI-only connection
			PseudoMultiplier (number): Multiplier for GUI-only connection
			PseudoMultiplierBfd (number): Multiplier for GUI-only connection
			PseudoMultiplierVxlanReplicator (number): Multiplier for GUI-only connection
			Role (list(str[master|none|slave])): The role of the OVSDB Controller.
			ServerAddDeleteConnectionError (str): API to retrieve error occured while Adding/ Deleting Server
			ServerAddDeleteStatus (str): Status of all servers Added/Deleted to Controller. Use Get Server Add/Delete Status, right click action to get current status
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.
			TimeOut (number): Transact request Time Out in seconds. For scale scenarios increase this Timeout value.
			Vxlan (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 
			VxlanReplicator (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): 

		Returns:
			self: This instance with matching ovsdbcontroller data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ovsdbcontroller data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ovsdbcontroller data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, ClearDumpDbFiles=None, ConnectionType=None, ControllerTcpPort=None, DirectoryName=None, DumpdbDirectoryName=None, EnableOvsdbServerIp=None, ErrorCode=None, ErrorDesc=None, ErrorLogDirectoryName=None, ErrorLogicalSwitchName=None, ErrorPhysicalSwitchName=None, ErrorTimeStamp=None, FileCaCertificate=None, FileCertificate=None, FileHWGatewayCertificate=None, FilePrivKey=None, HSCConfiguration=None, OvsdbSchema=None, OvsdbServerIp=None, ServerConnectionIp=None, TableNames=None, VerifyHWGatewayCertificate=None, VerifyPeerCertificate=None):
		"""Base class infrastructure that gets a list of ovsdbcontroller device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			ClearDumpDbFiles (str): optional regex of clearDumpDbFiles
			ConnectionType (str): optional regex of connectionType
			ControllerTcpPort (str): optional regex of controllerTcpPort
			DirectoryName (str): optional regex of directoryName
			DumpdbDirectoryName (str): optional regex of dumpdbDirectoryName
			EnableOvsdbServerIp (str): optional regex of enableOvsdbServerIp
			ErrorCode (str): optional regex of errorCode
			ErrorDesc (str): optional regex of errorDesc
			ErrorLogDirectoryName (str): optional regex of errorLogDirectoryName
			ErrorLogicalSwitchName (str): optional regex of errorLogicalSwitchName
			ErrorPhysicalSwitchName (str): optional regex of errorPhysicalSwitchName
			ErrorTimeStamp (str): optional regex of errorTimeStamp
			FileCaCertificate (str): optional regex of fileCaCertificate
			FileCertificate (str): optional regex of fileCertificate
			FileHWGatewayCertificate (str): optional regex of fileHWGatewayCertificate
			FilePrivKey (str): optional regex of filePrivKey
			HSCConfiguration (str): optional regex of hSCConfiguration
			OvsdbSchema (str): optional regex of ovsdbSchema
			OvsdbServerIp (str): optional regex of ovsdbServerIp
			ServerConnectionIp (str): optional regex of serverConnectionIp
			TableNames (str): optional regex of tableNames
			VerifyHWGatewayCertificate (str): optional regex of verifyHWGatewayCertificate
			VerifyPeerCertificate (str): optional regex of verifyPeerCertificate

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def AddServer(self, *args, **kwargs):
		"""Executes the addServer operation on the server.

		Add Server.

		addServer(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices for which to Add Server.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('addServer', payload=payload, response_object=None)

	def ClearLastErrors(self, *args, **kwargs):
		"""Executes the clearLastErrors operation on the server.

		Clear Error Messages reported due to Last Action.

		clearLastErrors(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices for which to clear last reported error messages.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearLastErrors', payload=payload, response_object=None)

	def ClearPortLogs(self, *args, **kwargs):
		"""Executes the clearPortLogs operation on the server.

		Add Server.

		clearPortLogs(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices for which to Add Server.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearPortLogs', payload=payload, response_object=None)

	def ControllerDumpDB(self, *args, **kwargs):
		"""Executes the controllerDumpDB operation on the server.

		Command to fetch Tor Information stored internally.

		controllerDumpDB(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the device group.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('controllerDumpDB', payload=payload, response_object=None)

	def DeleteServer(self, *args, **kwargs):
		"""Executes the deleteServer operation on the server.

		Delete Server.

		deleteServer(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices for which to Delete Server.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('deleteServer', payload=payload, response_object=None)

	def DumpDB(self, *args, **kwargs):
		"""Executes the dumpDB operation on the server.

		Attach.

		dumpDB(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the device group.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('dumpDB', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetServerAddDeleteStatus(self, *args, **kwargs):
		"""Executes the getServerAddDeleteStatus operation on the server.

		Get Server Status.

		getServerAddDeleteStatus(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices for which to get Server Status.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getServerAddDeleteStatus', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



"""Demonstrates creating a traffic item that uses ipv4 endpoints.

"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform

# connect to a test platform, create a session and get the root IxNetwork object
test_platform = TestPlatform('127.0.0.1', rest_port=11009)
test_platform.Trace = 'request_response'
sessions = test_platform.Sessions.find(Id=1)
ixnetwork = sessions.Ixnetwork

# clear the configuration
ixnetwork.NewConfig()

# create 2 ipv4 endpoints
ipv4_1 = ixnetwork.Topology.add(Vports=ixnetwork.Vport.add()).DeviceGroup.add().Ethernet.add().Ipv4.add(Name='Ipv4 West')
ipv4_2 = ixnetwork.Topology.add(Vports=ixnetwork.Vport.add()).DeviceGroup.add().Ethernet.add().Ipv4.add(Name='Ipv4 East')

# create an ipv4 traffic item
traffic_item = ixnetwork.Traffic.TrafficItem.add(Name='Ipv4 Traffic Item Sample', TrafficType='ipv4', TrafficItemType='l2L3')

# create an endpoint set using the ipv4 objects
endpoint_set = traffic_item.EndpointSet.add(Sources=ipv4_1, Destinations=ipv4_2)
assert (len(endpoint_set.Sources) == 1)
assert (len(endpoint_set.Destinations) == 1)
assert (len(traffic_item.ConfigElement.find().Stack.find(StackTypeId='ipv4')) == 1)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class JoinPrune(Base):
	"""The JoinPrune class encapsulates a user managed joinPrune node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the JoinPrune property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'joinPrune'

	def __init__(self, parent):
		super(JoinPrune, self).__init__(parent)

	@property
	def LearnedMgrState(self):
		"""An instance of the LearnedMgrState class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.pimsm.router.interface.joinprune.learnedmgrstate.learnedmgrstate.LearnedMgrState)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.pimsm.router.interface.joinprune.learnedmgrstate.learnedmgrstate import LearnedMgrState
		return LearnedMgrState(self)

	@property
	def DiscardRegisterStates(self):
		"""If checked, the Learned Join States sent by the RP (DUT) in response to this specific Register Message will be discarded - and will not be displayed in the table of the Register Range window.

		Returns:
			bool
		"""
		return self._get_attribute('discardRegisterStates')
	@DiscardRegisterStates.setter
	def DiscardRegisterStates(self, value):
		self._set_attribute('discardRegisterStates', value)

	@property
	def Enabled(self):
		"""Enables the use of this join/prune.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def EnabledDataMdt(self):
		"""If enabled, pimsmLearnedDataMdt will be available. (default = disabled)

		Returns:
			bool
		"""
		return self._get_attribute('enabledDataMdt')
	@EnabledDataMdt.setter
	def EnabledDataMdt(self, value):
		self._set_attribute('enabledDataMdt', value)

	@property
	def FlapEnabled(self):
		"""Enables emulated flapping of this multicast group range. NOTE: Flapping is not supported for the Switchover (*, G) -> (S, G) range type.

		Returns:
			bool
		"""
		return self._get_attribute('flapEnabled')
	@FlapEnabled.setter
	def FlapEnabled(self, value):
		self._set_attribute('flapEnabled', value)

	@property
	def FlapInterval(self):
		"""Defines the join/prune flapping interval.

		Returns:
			number
		"""
		return self._get_attribute('flapInterval')
	@FlapInterval.setter
	def FlapInterval(self, value):
		self._set_attribute('flapInterval', value)

	@property
	def GroupAddress(self):
		"""An IPv4 or IPv6 address used with the group mask to create a range of multicast addresses.

		Returns:
			str
		"""
		return self._get_attribute('groupAddress')
	@GroupAddress.setter
	def GroupAddress(self, value):
		self._set_attribute('groupAddress', value)

	@property
	def GroupCount(self):
		"""The number of multicast group addresses to be included in the multicast group range. The maximum number of valid possible addresses depends on the values for the group address and the group mask width.

		Returns:
			number
		"""
		return self._get_attribute('groupCount')
	@GroupCount.setter
	def GroupCount(self, value):
		self._set_attribute('groupCount', value)

	@property
	def GroupMappingMode(self):
		"""Sets the type of mapping that occurs when routes are advertised. This only applies for (S, G) and switchover types for MGR and is meaningful for RR.

		Returns:
			str(fullyMeshed|oneToOne)
		"""
		return self._get_attribute('groupMappingMode')
	@GroupMappingMode.setter
	def GroupMappingMode(self, value):
		self._set_attribute('groupMappingMode', value)

	@property
	def GroupMaskWidth(self):
		"""The number of bits in the mask applied to the group address. (The masked bits in the group address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type.

		Returns:
			number
		"""
		return self._get_attribute('groupMaskWidth')
	@GroupMaskWidth.setter
	def GroupMaskWidth(self, value):
		self._set_attribute('groupMaskWidth', value)

	@property
	def GroupRange(self):
		"""The multicast group range type.

		Returns:
			str(rp|g|sg|sptSwitchOver|registerTriggeredSg)
		"""
		return self._get_attribute('groupRange')
	@GroupRange.setter
	def GroupRange(self, value):
		self._set_attribute('groupRange', value)

	@property
	def NumRegToReceivePerSg(self):
		"""If rangeType is set to pimsmJoinsPrunesTypeRegisterTriggeredSG, then this is the count of register messages received that will trigger transmission of a (S,G) message. (default = 10)

		Returns:
			number
		"""
		return self._get_attribute('numRegToReceivePerSg')
	@NumRegToReceivePerSg.setter
	def NumRegToReceivePerSg(self, value):
		self._set_attribute('numRegToReceivePerSg', value)

	@property
	def PackGroupsEnabled(self):
		"""If enabled, multiple groups can be included within a single packet.

		Returns:
			bool
		"""
		return self._get_attribute('packGroupsEnabled')
	@PackGroupsEnabled.setter
	def PackGroupsEnabled(self, value):
		self._set_attribute('packGroupsEnabled', value)

	@property
	def PruneSourceAddress(self):
		"""ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages. (Multicast addresses are invalid.)

		Returns:
			str
		"""
		return self._get_attribute('pruneSourceAddress')
	@PruneSourceAddress.setter
	def PruneSourceAddress(self, value):
		self._set_attribute('pruneSourceAddress', value)

	@property
	def PruneSourceCount(self):
		"""The number of prune source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width. The default value is 0. ONLY used for (*,G) type to send (S,G,rpt) prune messages.

		Returns:
			number
		"""
		return self._get_attribute('pruneSourceCount')
	@PruneSourceCount.setter
	def PruneSourceCount(self, value):
		self._set_attribute('pruneSourceCount', value)

	@property
	def PruneSourceMaskWidth(self):
		"""The number of bits in the mask applied to the prune source address. (The masked bits in the prune source address form the address prefix.)

		Returns:
			number
		"""
		return self._get_attribute('pruneSourceMaskWidth')
	@PruneSourceMaskWidth.setter
	def PruneSourceMaskWidth(self, value):
		self._set_attribute('pruneSourceMaskWidth', value)

	@property
	def RpAddress(self):
		"""The IP address of the Rendezvous Point (RP) router.

		Returns:
			str
		"""
		return self._get_attribute('rpAddress')
	@RpAddress.setter
	def RpAddress(self, value):
		self._set_attribute('rpAddress', value)

	@property
	def SourceAddress(self):
		"""The Multicast Source Address. Used for (S,G) Type and (S,G, rpt) only. (Multicast addresses are invalid.)

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress')
	@SourceAddress.setter
	def SourceAddress(self, value):
		self._set_attribute('sourceAddress', value)

	@property
	def SourceCount(self):
		"""The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width.

		Returns:
			number
		"""
		return self._get_attribute('sourceCount')
	@SourceCount.setter
	def SourceCount(self, value):
		self._set_attribute('sourceCount', value)

	@property
	def SourceMaskWidth(self):
		"""The number of bits in the mask applied to the source address. (The masked bits in the source address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type. Used for (S,G) Type and (S,G, rpt) only.

		Returns:
			number
		"""
		return self._get_attribute('sourceMaskWidth')
	@SourceMaskWidth.setter
	def SourceMaskWidth(self, value):
		self._set_attribute('sourceMaskWidth', value)

	@property
	def SptSwitchoverInterval(self):
		"""The time interval (in seconds) allowed for the switch from using the RP tree to using a Source-specific tree - from (*,G) to (S,G). The default value is 0.

		Returns:
			number
		"""
		return self._get_attribute('sptSwitchoverInterval')
	@SptSwitchoverInterval.setter
	def SptSwitchoverInterval(self, value):
		self._set_attribute('sptSwitchoverInterval', value)

	def update(self, DiscardRegisterStates=None, Enabled=None, EnabledDataMdt=None, FlapEnabled=None, FlapInterval=None, GroupAddress=None, GroupCount=None, GroupMappingMode=None, GroupMaskWidth=None, GroupRange=None, NumRegToReceivePerSg=None, PackGroupsEnabled=None, PruneSourceAddress=None, PruneSourceCount=None, PruneSourceMaskWidth=None, RpAddress=None, SourceAddress=None, SourceCount=None, SourceMaskWidth=None, SptSwitchoverInterval=None):
		"""Updates a child instance of joinPrune on the server.

		Args:
			DiscardRegisterStates (bool): If checked, the Learned Join States sent by the RP (DUT) in response to this specific Register Message will be discarded - and will not be displayed in the table of the Register Range window.
			Enabled (bool): Enables the use of this join/prune.
			EnabledDataMdt (bool): If enabled, pimsmLearnedDataMdt will be available. (default = disabled)
			FlapEnabled (bool): Enables emulated flapping of this multicast group range. NOTE: Flapping is not supported for the Switchover (*, G) -> (S, G) range type.
			FlapInterval (number): Defines the join/prune flapping interval.
			GroupAddress (str): An IPv4 or IPv6 address used with the group mask to create a range of multicast addresses.
			GroupCount (number): The number of multicast group addresses to be included in the multicast group range. The maximum number of valid possible addresses depends on the values for the group address and the group mask width.
			GroupMappingMode (str(fullyMeshed|oneToOne)): Sets the type of mapping that occurs when routes are advertised. This only applies for (S, G) and switchover types for MGR and is meaningful for RR.
			GroupMaskWidth (number): The number of bits in the mask applied to the group address. (The masked bits in the group address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type.
			GroupRange (str(rp|g|sg|sptSwitchOver|registerTriggeredSg)): The multicast group range type.
			NumRegToReceivePerSg (number): If rangeType is set to pimsmJoinsPrunesTypeRegisterTriggeredSG, then this is the count of register messages received that will trigger transmission of a (S,G) message. (default = 10)
			PackGroupsEnabled (bool): If enabled, multiple groups can be included within a single packet.
			PruneSourceAddress (str): ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages. (Multicast addresses are invalid.)
			PruneSourceCount (number): The number of prune source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width. The default value is 0. ONLY used for (*,G) type to send (S,G,rpt) prune messages.
			PruneSourceMaskWidth (number): The number of bits in the mask applied to the prune source address. (The masked bits in the prune source address form the address prefix.)
			RpAddress (str): The IP address of the Rendezvous Point (RP) router.
			SourceAddress (str): The Multicast Source Address. Used for (S,G) Type and (S,G, rpt) only. (Multicast addresses are invalid.)
			SourceCount (number): The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width.
			SourceMaskWidth (number): The number of bits in the mask applied to the source address. (The masked bits in the source address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type. Used for (S,G) Type and (S,G, rpt) only.
			SptSwitchoverInterval (number): The time interval (in seconds) allowed for the switch from using the RP tree to using a Source-specific tree - from (*,G) to (S,G). The default value is 0.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, DiscardRegisterStates=None, Enabled=None, EnabledDataMdt=None, FlapEnabled=None, FlapInterval=None, GroupAddress=None, GroupCount=None, GroupMappingMode=None, GroupMaskWidth=None, GroupRange=None, NumRegToReceivePerSg=None, PackGroupsEnabled=None, PruneSourceAddress=None, PruneSourceCount=None, PruneSourceMaskWidth=None, RpAddress=None, SourceAddress=None, SourceCount=None, SourceMaskWidth=None, SptSwitchoverInterval=None):
		"""Adds a new joinPrune node on the server and retrieves it in this instance.

		Args:
			DiscardRegisterStates (bool): If checked, the Learned Join States sent by the RP (DUT) in response to this specific Register Message will be discarded - and will not be displayed in the table of the Register Range window.
			Enabled (bool): Enables the use of this join/prune.
			EnabledDataMdt (bool): If enabled, pimsmLearnedDataMdt will be available. (default = disabled)
			FlapEnabled (bool): Enables emulated flapping of this multicast group range. NOTE: Flapping is not supported for the Switchover (*, G) -> (S, G) range type.
			FlapInterval (number): Defines the join/prune flapping interval.
			GroupAddress (str): An IPv4 or IPv6 address used with the group mask to create a range of multicast addresses.
			GroupCount (number): The number of multicast group addresses to be included in the multicast group range. The maximum number of valid possible addresses depends on the values for the group address and the group mask width.
			GroupMappingMode (str(fullyMeshed|oneToOne)): Sets the type of mapping that occurs when routes are advertised. This only applies for (S, G) and switchover types for MGR and is meaningful for RR.
			GroupMaskWidth (number): The number of bits in the mask applied to the group address. (The masked bits in the group address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type.
			GroupRange (str(rp|g|sg|sptSwitchOver|registerTriggeredSg)): The multicast group range type.
			NumRegToReceivePerSg (number): If rangeType is set to pimsmJoinsPrunesTypeRegisterTriggeredSG, then this is the count of register messages received that will trigger transmission of a (S,G) message. (default = 10)
			PackGroupsEnabled (bool): If enabled, multiple groups can be included within a single packet.
			PruneSourceAddress (str): ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages. (Multicast addresses are invalid.)
			PruneSourceCount (number): The number of prune source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width. The default value is 0. ONLY used for (*,G) type to send (S,G,rpt) prune messages.
			PruneSourceMaskWidth (number): The number of bits in the mask applied to the prune source address. (The masked bits in the prune source address form the address prefix.)
			RpAddress (str): The IP address of the Rendezvous Point (RP) router.
			SourceAddress (str): The Multicast Source Address. Used for (S,G) Type and (S,G, rpt) only. (Multicast addresses are invalid.)
			SourceCount (number): The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width.
			SourceMaskWidth (number): The number of bits in the mask applied to the source address. (The masked bits in the source address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type. Used for (S,G) Type and (S,G, rpt) only.
			SptSwitchoverInterval (number): The time interval (in seconds) allowed for the switch from using the RP tree to using a Source-specific tree - from (*,G) to (S,G). The default value is 0.

		Returns:
			self: This instance with all currently retrieved joinPrune data using find and the newly added joinPrune data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the joinPrune data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, DiscardRegisterStates=None, Enabled=None, EnabledDataMdt=None, FlapEnabled=None, FlapInterval=None, GroupAddress=None, GroupCount=None, GroupMappingMode=None, GroupMaskWidth=None, GroupRange=None, NumRegToReceivePerSg=None, PackGroupsEnabled=None, PruneSourceAddress=None, PruneSourceCount=None, PruneSourceMaskWidth=None, RpAddress=None, SourceAddress=None, SourceCount=None, SourceMaskWidth=None, SptSwitchoverInterval=None):
		"""Finds and retrieves joinPrune data from the server.

		All named parameters support regex and can be used to selectively retrieve joinPrune data from the server.
		By default the find method takes no parameters and will retrieve all joinPrune data from the server.

		Args:
			DiscardRegisterStates (bool): If checked, the Learned Join States sent by the RP (DUT) in response to this specific Register Message will be discarded - and will not be displayed in the table of the Register Range window.
			Enabled (bool): Enables the use of this join/prune.
			EnabledDataMdt (bool): If enabled, pimsmLearnedDataMdt will be available. (default = disabled)
			FlapEnabled (bool): Enables emulated flapping of this multicast group range. NOTE: Flapping is not supported for the Switchover (*, G) -> (S, G) range type.
			FlapInterval (number): Defines the join/prune flapping interval.
			GroupAddress (str): An IPv4 or IPv6 address used with the group mask to create a range of multicast addresses.
			GroupCount (number): The number of multicast group addresses to be included in the multicast group range. The maximum number of valid possible addresses depends on the values for the group address and the group mask width.
			GroupMappingMode (str(fullyMeshed|oneToOne)): Sets the type of mapping that occurs when routes are advertised. This only applies for (S, G) and switchover types for MGR and is meaningful for RR.
			GroupMaskWidth (number): The number of bits in the mask applied to the group address. (The masked bits in the group address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type.
			GroupRange (str(rp|g|sg|sptSwitchOver|registerTriggeredSg)): The multicast group range type.
			NumRegToReceivePerSg (number): If rangeType is set to pimsmJoinsPrunesTypeRegisterTriggeredSG, then this is the count of register messages received that will trigger transmission of a (S,G) message. (default = 10)
			PackGroupsEnabled (bool): If enabled, multiple groups can be included within a single packet.
			PruneSourceAddress (str): ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages. (Multicast addresses are invalid.)
			PruneSourceCount (number): The number of prune source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width. The default value is 0. ONLY used for (*,G) type to send (S,G,rpt) prune messages.
			PruneSourceMaskWidth (number): The number of bits in the mask applied to the prune source address. (The masked bits in the prune source address form the address prefix.)
			RpAddress (str): The IP address of the Rendezvous Point (RP) router.
			SourceAddress (str): The Multicast Source Address. Used for (S,G) Type and (S,G, rpt) only. (Multicast addresses are invalid.)
			SourceCount (number): The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the source address and the source mask width.
			SourceMaskWidth (number): The number of bits in the mask applied to the source address. (The masked bits in the source address form the address prefix.)The default value is 32. The valid range is 1 to 128, depending on address family type. Used for (S,G) Type and (S,G, rpt) only.
			SptSwitchoverInterval (number): The time interval (in seconds) allowed for the switch from using the RP tree to using a Source-specific tree - from (*,G) to (S,G). The default value is 0.

		Returns:
			self: This instance with matching joinPrune data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of joinPrune data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the joinPrune data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Lan(Base):
	"""The Lan class encapsulates a user managed lan node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Lan property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'lan'

	def __init__(self, parent):
		super(Lan, self).__init__(parent)

	@property
	def Enabled(self):
		"""Enables the use of the STP LAN.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def MacAddress(self):
		"""The first 6-byte MAC Address in the range. (default = 00:00:00:00:00:00)

		Returns:
			str
		"""
		return self._get_attribute('macAddress')
	@MacAddress.setter
	def MacAddress(self, value):
		self._set_attribute('macAddress', value)

	@property
	def MacCount(self):
		"""The number of MAC addresses in the LAN range. The valid range is 1 to 500. (default = 1)

		Returns:
			number
		"""
		return self._get_attribute('macCount')
	@MacCount.setter
	def MacCount(self, value):
		self._set_attribute('macCount', value)

	@property
	def MacIncrement(self):
		"""If enabled, a 6-byte increment value will be added for each additional MAC address to create a range of MAC addresses.

		Returns:
			bool
		"""
		return self._get_attribute('macIncrement')
	@MacIncrement.setter
	def MacIncrement(self, value):
		self._set_attribute('macIncrement', value)

	@property
	def TrafficGroupId(self):
		"""References a traffic group identifier as configured by the trafficGroup object.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	@property
	def VlanEnabled(self):
		"""Enables the use of this STP LAN. (default = disabled)

		Returns:
			bool
		"""
		return self._get_attribute('vlanEnabled')
	@VlanEnabled.setter
	def VlanEnabled(self, value):
		self._set_attribute('vlanEnabled', value)

	@property
	def VlanId(self):
		"""The identifier for the first VLAN in the range. Valid range: 1 to 4094.

		Returns:
			number
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	@property
	def VlanIncrement(self):
		"""If enabled, an increment value will be added for each additional VLAN to create a range of MAC addresses.

		Returns:
			bool
		"""
		return self._get_attribute('vlanIncrement')
	@VlanIncrement.setter
	def VlanIncrement(self, value):
		self._set_attribute('vlanIncrement', value)

	def update(self, Enabled=None, MacAddress=None, MacCount=None, MacIncrement=None, TrafficGroupId=None, VlanEnabled=None, VlanId=None, VlanIncrement=None):
		"""Updates a child instance of lan on the server.

		Args:
			Enabled (bool): Enables the use of the STP LAN.
			MacAddress (str): The first 6-byte MAC Address in the range. (default = 00:00:00:00:00:00)
			MacCount (number): The number of MAC addresses in the LAN range. The valid range is 1 to 500. (default = 1)
			MacIncrement (bool): If enabled, a 6-byte increment value will be added for each additional MAC address to create a range of MAC addresses.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): References a traffic group identifier as configured by the trafficGroup object.
			VlanEnabled (bool): Enables the use of this STP LAN. (default = disabled)
			VlanId (number): The identifier for the first VLAN in the range. Valid range: 1 to 4094.
			VlanIncrement (bool): If enabled, an increment value will be added for each additional VLAN to create a range of MAC addresses.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Enabled=None, MacAddress=None, MacCount=None, MacIncrement=None, TrafficGroupId=None, VlanEnabled=None, VlanId=None, VlanIncrement=None):
		"""Adds a new lan node on the server and retrieves it in this instance.

		Args:
			Enabled (bool): Enables the use of the STP LAN.
			MacAddress (str): The first 6-byte MAC Address in the range. (default = 00:00:00:00:00:00)
			MacCount (number): The number of MAC addresses in the LAN range. The valid range is 1 to 500. (default = 1)
			MacIncrement (bool): If enabled, a 6-byte increment value will be added for each additional MAC address to create a range of MAC addresses.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): References a traffic group identifier as configured by the trafficGroup object.
			VlanEnabled (bool): Enables the use of this STP LAN. (default = disabled)
			VlanId (number): The identifier for the first VLAN in the range. Valid range: 1 to 4094.
			VlanIncrement (bool): If enabled, an increment value will be added for each additional VLAN to create a range of MAC addresses.

		Returns:
			self: This instance with all currently retrieved lan data using find and the newly added lan data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the lan data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Enabled=None, MacAddress=None, MacCount=None, MacIncrement=None, TrafficGroupId=None, VlanEnabled=None, VlanId=None, VlanIncrement=None):
		"""Finds and retrieves lan data from the server.

		All named parameters support regex and can be used to selectively retrieve lan data from the server.
		By default the find method takes no parameters and will retrieve all lan data from the server.

		Args:
			Enabled (bool): Enables the use of the STP LAN.
			MacAddress (str): The first 6-byte MAC Address in the range. (default = 00:00:00:00:00:00)
			MacCount (number): The number of MAC addresses in the LAN range. The valid range is 1 to 500. (default = 1)
			MacIncrement (bool): If enabled, a 6-byte increment value will be added for each additional MAC address to create a range of MAC addresses.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): References a traffic group identifier as configured by the trafficGroup object.
			VlanEnabled (bool): Enables the use of this STP LAN. (default = disabled)
			VlanId (number): The identifier for the first VLAN in the range. Valid range: 1 to 4094.
			VlanIncrement (bool): If enabled, an increment value will be added for each additional VLAN to create a range of MAC addresses.

		Returns:
			self: This instance with matching lan data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of lan data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the lan data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
